@@ -1,10 +1,8 @@
 package Business::MaxMind;
-# git description: v1.56-10-g746bf18
-
 
 use 5.006;
 
-our $VERSION = '1.57';
+our $VERSION = '1.60';
 
 1;
 
@@ -20,7 +18,7 @@ Business::MaxMind - API for MaxMind minFraud Services
 
 =head1 VERSION
 
-version 1.57
+version 1.60
 
 =head1 DESCRIPTION
 
@@ -40,6 +38,30 @@ Frank Mather <frank@maxmind.com>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Boris Zentner Dave Rolsky Greg Oschwald Mateu X Hunter
+
+=over 4
+
+=item *
+
+Boris Zentner <bzentner@maxmind.com>
+
+=item *
+
+Dave Rolsky <drolsky@maxmind.com>
+
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Mateu X Hunter <mhunter@maxmind.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2015 by MaxMind, Inc..
